@@ -3,8 +3,8 @@
 namespace Icinga\Module\Director\Db;
 
 use Exception;
-use Icinga\Exception\IcingaException;
 use Icinga\Module\Director\Data\Db\DbConnection;
+use RuntimeException;
 
 class Migration
 {
@@ -24,18 +24,28 @@ class Migration
         $this->sql     = $sql;
     }
 
+    /**
+     * @param DbConnection $connection
+     * @return $this
+     */
     public function apply(DbConnection $connection)
     {
+        /** @var \Zend_Db_Adapter_Pdo_Abstract $db */
         $db = $connection->getDbAdapter();
 
-        // TODO: this is fagile and depends on accordingly written schema files:
-        $queries = preg_split('/[\n\s\t]*\;[\n\s\t]+/s', $this->sql, -1, PREG_SPLIT_NO_EMPTY);
+        // TODO: this is fragile and depends on accordingly written schema files:
+        $queries = preg_split(
+            '/[\n\s\t]*\;[\n\s\t]+/s',
+            $this->sql,
+            -1,
+            PREG_SPLIT_NO_EMPTY
+        );
 
         if (empty($queries)) {
-            throw new IcingaException(
+            throw new RuntimeException(sprintf(
                 'Migration %d has no queries',
                 $this->version
-            );
+            ));
         }
 
         try {
@@ -47,12 +57,12 @@ class Migration
                 }
             }
         } catch (Exception $e) {
-            throw new IcingaException(
+            throw new RuntimeException(sprintf(
                 'Migration %d failed (%s) while running %s',
                 $this->version,
                 $e->getMessage(),
                 $query
-            );
+            ));
         }
 
         return $this;
