@@ -29,6 +29,7 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         'ignore_soft_states'     => null,
         'period_id'              => null,
         'zone_id'                => null,
+        'redundancy_group'       => null,
         'assign_filter'          => null,
         'parent_service_by_name' => null,
     ];
@@ -408,7 +409,8 @@ class IcingaDependency extends IcingaObject implements ExportInterface
     public function renderChild_service_id()
     {
         // @codingStandardsIgnoreEnd
-        if ($this->hasBeenAssignedToServiceTemplate()
+        if (
+            $this->hasBeenAssignedToServiceTemplate()
             || $this->hasBeenAssignedToHostTemplateService()
             || $this->hasBeenAssignedToServiceApply()
         ) {
@@ -467,7 +469,8 @@ class IcingaDependency extends IcingaObject implements ExportInterface
 
     public function isApplyRule()
     {
-        if ($this->hasBeenAssignedToHostTemplate()
+        if (
+            $this->hasBeenAssignedToHostTemplate()
             || $this->hasBeenAssignedToServiceTemplate()
             || $this->hasBeenAssignedToServiceApply()
         ) {
@@ -612,7 +615,8 @@ class IcingaDependency extends IcingaObject implements ExportInterface
         $related = parent::getRelatedProperty($key);
         // handle special case for plain string parent service on Dependency
         // Apply rules
-        if ($related === null
+        if (
+            $related === null
             && $key === 'parent_service'
             && (
                 $this->get('parent_service_by_name')
