@@ -132,7 +132,7 @@ class ImportSource extends DbObjectWithSettings implements ExportInterface
     protected static function existsWithNameAndId($name, $id, Db $connection)
     {
         $db = $connection->getDbAdapter();
-        $dummy = new static;
+        $dummy = new static();
         $idCol = $dummy->autoincKeyName;
         $keyCol = $dummy->keyName;
 
