@@ -7,9 +7,14 @@ use Icinga\Exception\IcingaException;
 use Icinga\Exception\NotFoundError;
 use Icinga\Exception\ProgrammingError;
 use Icinga\Module\Director\Core\CoreApi;
+use Icinga\Module\Director\Data\Exporter;
+use Icinga\Module\Director\DirectorObject\Lookup\ServiceFinder;
 use Icinga\Module\Director\Exception\DuplicateKeyException;
+use Icinga\Module\Director\Objects\IcingaHost;
 use Icinga\Module\Director\Objects\IcingaObject;
-use Icinga\Module\Director\Util;
+use Icinga\Module\Director\Resolver\OverrideHelper;
+use InvalidArgumentException;
+use RuntimeException;
 
 class IcingaObjectHandler extends RequestHandler
 {
@@ -47,7 +52,7 @@ class IcingaObjectHandler extends RequestHandler
     /**
      * @return IcingaObject
      */
-    protected function eventuallyLoadObject()
+    protected function loadOptionalObject()
     {
         return $this->object;
     }
@@ -94,7 +99,6 @@ class IcingaObjectHandler extends RequestHandler
     protected function handleApiRequest()
     {
         $request = $this->request;
-        $response = $this->response;
         $db = $this->db;
 
         // TODO: I hate doing this:
@@ -105,12 +109,7 @@ class IcingaObjectHandler extends RequestHandler
                 throw new NotFoundError('The host "%s" is not an agent', $host->getObjectName());
             }
 
-            $this->sendJson(
-                Util::getIcingaTicket(
-                    $host->getObjectName(),
-                    $this->api->getTicketSalt()
-                )
-            );
+            $this->sendJson($this->api->getTicket($host->getObjectName()));
 
             // TODO: find a better way to shut down. Currently, this avoids
             //       "not found" errors:
@@ -127,8 +126,10 @@ class IcingaObjectHandler extends RequestHandler
             case 'POST':
             case 'PUT':
                 $data = (array) $this->requireJsonBody();
+                $params = $this->request->getUrl()->getParams();
+                $allowsOverrides = $params->get('allowOverrides');
                 $type = $this->getType();
-                if ($object = $this->eventuallyLoadObject()) {
+                if ($object = $this->loadOptionalObject()) {
                     if ($request->getMethod() === 'POST') {
                         $object->setProperties($data);
                     } else {
@@ -136,42 +137,42 @@ class IcingaObjectHandler extends RequestHandler
                             'object_type' => $object->get('object_type'),
                             'object_name' => $object->getObjectName()
                         ], $data);
-                        $object->replaceWith(
-                            IcingaObject::createByType($type, $data, $db)
+                        $object->replaceWith(IcingaObject::createByType($type, $data, $db));
+                    }
+
+                    if (in_array((int) $object->get('id'), $object->listAncestorIds())) {
+                        throw new RuntimeException(
+                            'Import loop detected for the object '
+                            . $object->getObjectName() . ' -> Imports: '
+                            . implode(', ', $object->getImports())
                         );
                     }
+
+                    if (isset($data['imports']) && in_array($object->get('object_name'), $data['imports'])) {
+                        throw new RuntimeException(
+                            'You can not import the same object into itself: ' . $object->getObjectName()
+                        );
+                    }
+
+                    $this->persistChanges($object);
+                    $this->sendJson($object->toPlainObject(false, true));
+                } elseif ($allowsOverrides && $type === 'service') {
+                    if ($request->getMethod() === 'PUT') {
+                        throw new InvalidArgumentException('Overrides are not (yet) available for HTTP PUT');
+                    }
+                    $this->setServiceProperties($params->getRequired('host'), $params->getRequired('name'), $data);
                 } else {
                     $object = IcingaObject::createByType($type, $data, $db);
+                    $this->persistChanges($object);
+                    $this->sendJson($object->toPlainObject(false, true));
                 }
-
-                if ($object->hasBeenModified()) {
-                    $status = $object->hasBeenLoadedFromDb() ? 200 : 201;
-                    $object->store();
-                    $response->setHttpResponseCode($status);
-                } else {
-                    $response->setHttpResponseCode(304);
-                }
-
-                $this->sendJson($object->toPlainObject(false, true));
                 break;
 
             case 'GET':
-                $params = $this->request->getUrl()->getParams();
-                $this->requireObject();
-                $properties = $params->shift('properties');
-                if (strlen($properties)) {
-                    $properties = preg_split('/\s*,\s*/', $properties, -1, PREG_SPLIT_NO_EMPTY);
-                } else {
-                    $properties = null;
-                }
-
-                $this->sendJson(
-                    $this->requireObject()->toPlainObject(
-                        $params->shift('resolved'),
-                        ! $params->shift('withNull'),
-                        $properties
-                    )
-                );
+                $object = $this->requireObject();
+                $exporter = new Exporter($this->db);
+                RestApiParams::applyParamsToExporter($exporter, $this->request, $object->getShortTableName());
+                $this->sendJson($exporter->export($object));
                 break;
 
             default:
@@ -179,4 +180,32 @@ class IcingaObjectHandler extends RequestHandler
                 throw new IcingaException('Unsupported method ' . $request->getMethod());
         }
     }
+
+    protected function persistChanges(IcingaObject $object)
+    {
+        if ($object->hasBeenModified()) {
+            $status = $object->hasBeenLoadedFromDb() ? 200 : 201;
+            $object->store();
+            $this->response->setHttpResponseCode($status);
+        } else {
+            $this->response->setHttpResponseCode(304);
+        }
+    }
+
+    protected function setServiceProperties($hostname, $serviceName, $properties)
+    {
+        $host = IcingaHost::load($hostname, $this->db);
+        $service = ServiceFinder::find($host, $serviceName);
+        if ($service === false) {
+            throw new NotFoundError('Not found');
+        }
+        if ($service->requiresOverrides()) {
+            unset($properties['host']);
+            OverrideHelper::applyOverriddenVars($host, $serviceName, $properties);
+            $this->persistChanges($host);
+            $this->sendJson($host->toPlainObject(false, true));
+        } else {
+            throw new RuntimeException('Found a single service, which should have been found (and dealt with) before');
+        }
+    }
 }
