@@ -5,6 +5,7 @@ namespace Icinga\Module\Director\Web\Form;
 use Exception;
 use gipfl\IcingaWeb2\Url;
 use Icinga\Authentication\Auth;
+use Icinga\Module\Director\Auth\Permission;
 use Icinga\Module\Director\Data\Db\DbObjectStore;
 use Icinga\Module\Director\Db;
 use Icinga\Module\Director\Data\Db\DbObject;
@@ -17,24 +18,26 @@ use Icinga\Module\Director\IcingaConfig\TypeFilterSet;
 use Icinga\Module\Director\Objects\IcingaTemplateChoice;
 use Icinga\Module\Director\Objects\IcingaCommand;
 use Icinga\Module\Director\Objects\IcingaObject;
+use Icinga\Module\Director\Resolver\TemplateTree;
 use Icinga\Module\Director\Util;
 use Icinga\Module\Director\Web\Form\Element\ExtensibleSet;
 use Icinga\Module\Director\Web\Form\Validate\NamePattern;
 use Zend_Form_Element as ZfElement;
 use Zend_Form_Element_Select as ZfSelect;
+use Zend_Validate_Callback;
 
 abstract class DirectorObjectForm extends DirectorForm
 {
-    const GROUP_ORDER_OBJECT_DEFINITION = 20;
-    const GROUP_ORDER_RELATED_OBJECTS = 25;
-    const GROUP_ORDER_ASSIGN = 30;
-    const GROUP_ORDER_CHECK_EXECUTION = 40;
-    const GROUP_ORDER_CUSTOM_FIELDS = 50;
-    const GROUP_ORDER_CUSTOM_FIELD_CATEGORIES = 60;
-    const GROUP_ORDER_EVENT_FILTERS = 700;
-    const GROUP_ORDER_EXTRA_INFO = 750;
-    const GROUP_ORDER_CLUSTERING = 800;
-    const GROUP_ORDER_BUTTONS = 1000;
+    public const GROUP_ORDER_OBJECT_DEFINITION = 20;
+    public const GROUP_ORDER_RELATED_OBJECTS = 25;
+    public const GROUP_ORDER_ASSIGN = 30;
+    public const GROUP_ORDER_CHECK_EXECUTION = 40;
+    public const GROUP_ORDER_CUSTOM_FIELDS = 50;
+    public const GROUP_ORDER_CUSTOM_FIELD_CATEGORIES = 60;
+    public const GROUP_ORDER_EVENT_FILTERS = 700;
+    public const GROUP_ORDER_EXTRA_INFO = 750;
+    public const GROUP_ORDER_CLUSTERING = 800;
+    public const GROUP_ORDER_BUTTONS = 1000;
 
     /** @var IcingaObject */
     protected $object;
@@ -443,7 +446,7 @@ abstract class DirectorObjectForm extends DirectorForm
                         $this->setInheritedValue(
                             $el,
                             $object->getRelatedObjectName($k, $v),
-                            $origins->{"${k}_id"}
+                            $origins->{"{$k}_id"}
                         );
                     }
                 }
@@ -540,7 +543,9 @@ abstract class DirectorObjectForm extends DirectorForm
             'inherited_groups',
             'applied_groups',
             'users',
+            'users_var',
             'user_groups',
+            'user_groups_var',
             'apply_to',
             'command_id', // Notification
             'notification_interval',
@@ -550,6 +555,7 @@ abstract class DirectorObjectForm extends DirectorForm
             'email',
             'pager',
             'enable_notifications',
+            'redundancy_group', //Dependencies
             'disable_checks', //Dependencies
             'disable_notifications',
             'ignore_soft_states',
@@ -788,7 +794,9 @@ abstract class DirectorObjectForm extends DirectorForm
             return;
         }
 
-        $post = $values = $this->getRequest()->getPost();
+        /** @var array $post */
+        $post = $this->getRequest()->getPost();
+        $values = $post;
 
         foreach ($post as $key => $value) {
             if (preg_match('/^(.+?)_(\d+)__(MOVE_DOWN|MOVE_UP|REMOVE)$/', $key, $m)) {
@@ -1239,7 +1247,7 @@ abstract class DirectorObjectForm extends DirectorForm
                 if ($this->hasBeenSent()) {
                     $this->addError($this->translate('No template has been chosen'));
                 } else {
-                    if ($this->hasPermission('director/admin')) {
+                    if ($this->hasPermission(Permission::ADMIN)) {
                         $html = $this->translate('Please define a related template first');
                     } else {
                         $html = $this->translate('No related template has been provided yet');
@@ -1274,11 +1282,44 @@ abstract class DirectorObjectForm extends DirectorForm
             'required'     => $required,
             'spellcheck'   => 'false',
             'hideOptions'  => $choiceNames,
-            'suggest'      => "${type}templates",
+            'suggest'      => "{$type}templates",
             // 'multiOptions' => $this->optionallyAddFromEnum($enum),
             'sorted'       => true,
             'value'        => $this->presetImports,
-            'class'        => 'autosubmit'
+            'class'        => 'autosubmit',
+            'validators'   => [
+                new Zend_Validate_Callback(function ($value) {
+                    $templateTree = new TemplateTree($this->object->getShortTableName(), $this->getDb());
+                    $importsElement = $this->getElement('imports');
+                    $objectName = $this->object->getObjectName();
+                    if (in_array($objectName, $value, true)) {
+                        $importsElement->addErrorMessage(
+                            $this->translate('You can not import the same object into itself, please remove it first')
+                        );
+
+                        return false;
+                    }
+
+                    if ($this->object->isTemplate()) {
+                        $descendents = $templateTree->getDescendantsFor($this->object);
+                        $loopedImports = array_intersect($templateTree->getDescendantsFor($this->object), $value);
+                        if (! empty($loopedImports)) {
+                            $loopedImport = array_slice($loopedImports, 0, 1);
+                            array_push($loopedImport, ...$descendents);
+                            $importsElement->addErrorMessage(
+                                sprintf(
+                                    $this->translate('Loop detected for imports: %s'),
+                                    implode('->', $loopedImports)
+                                )
+                            );
+
+                            return false;
+                        }
+                    }
+
+                    return true;
+                })
+            ]
         ));
 
         return $this;
@@ -1516,6 +1557,7 @@ abstract class DirectorObjectForm extends DirectorForm
             return [];
         }
 
+        /** @var int|string $id */
         $id = $object->get('id');
 
         if (array_key_exists($id, $tpl)) {
