@@ -4,8 +4,8 @@ use Icinga\Application\Modules\Module;
 use Icinga\Module\Director\DataType\DataTypeArray;
 use Icinga\Module\Director\DataType\DataTypeBoolean;
 use Icinga\Module\Director\DataType\DataTypeDatalist;
-use Icinga\Module\Director\DataType\DataTypeDirectorObject;
 use Icinga\Module\Director\DataType\DataTypeDictionary;
+use Icinga\Module\Director\DataType\DataTypeDirectorObject;
 use Icinga\Module\Director\DataType\DataTypeNumber;
 use Icinga\Module\Director\DataType\DataTypeSqlQuery;
 use Icinga\Module\Director\DataType\DataTypeString;
@@ -73,6 +73,9 @@ if ($this->getConfig()->get('frontend', 'disabled', 'no') !== 'yes') {
     $this->provideHook('cube/IcingaDbActions', IcingaDbCubeLinks::class);
 }
 
+$this->provideHook('Icingadb/CustomVarRenderer', null, true);
+$this->provideHook('Monitoring/CustomVarRenderer', null, true);
+
 $directorHooks = [
     'director/DataType' => [
         DataTypeArray::class,
