@@ -35,8 +35,8 @@ CREATE TABLE director_activity_log (
   object_type VARCHAR(64) NOT NULL,
   object_name VARCHAR(255) NOT NULL,
   action_name ENUM('create', 'delete', 'modify') NOT NULL,
-  old_properties TEXT DEFAULT NULL COMMENT 'Property hash, JSON',
-  new_properties TEXT DEFAULT NULL COMMENT 'Property hash, JSON',
+  old_properties MEDIUMTEXT DEFAULT NULL COMMENT 'Property hash, JSON',
+  new_properties MEDIUMTEXT DEFAULT NULL COMMENT 'Property hash, JSON',
   author VARCHAR(64) NOT NULL,
   change_time TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
   checksum VARBINARY(20) NOT NULL,
@@ -46,7 +46,7 @@ CREATE TABLE director_activity_log (
   INDEX search_idx (object_name),
   INDEX search_idx2 (object_type(32), object_name(64), change_time),
   INDEX search_author (author),
-  INDEX checksum (checksum)
+  UNIQUE INDEX checksum (checksum)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
 CREATE TABLE director_activity_log_remark (
@@ -114,7 +114,7 @@ CREATE TABLE director_generated_config (
   last_activity_checksum VARBINARY(20) NOT NULL,
   PRIMARY KEY (checksum),
   CONSTRAINT director_generated_config_activity
-    FOREIGN KEY activity_checksum (last_activity_checksum)
+    FOREIGN KEY (last_activity_checksum)
     REFERENCES director_activity_log (checksum)
     ON DELETE RESTRICT
     ON UPDATE RESTRICT
@@ -167,6 +167,7 @@ CREATE TABLE director_deployment_log (
   username VARCHAR(64) DEFAULT NULL COMMENT 'The user that triggered this deployment',
   startup_log MEDIUMTEXT DEFAULT NULL,
   PRIMARY KEY (id),
+  INDEX (start_time),
   CONSTRAINT config_checksum
     FOREIGN KEY config_checksum (config_checksum)
     REFERENCES director_generated_config (checksum)
@@ -176,6 +177,7 @@ CREATE TABLE director_deployment_log (
 
 CREATE TABLE director_datalist (
   id INT(10) UNSIGNED AUTO_INCREMENT NOT NULL,
+  uuid VARBINARY(16) NOT NULL,
   list_name VARCHAR(255) NOT NULL,
   owner VARCHAR(255) NOT NULL,
   PRIMARY KEY (id),
@@ -206,6 +208,7 @@ CREATE TABLE director_datafield_category (
 
 CREATE TABLE director_datafield (
   id INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
+  uuid VARBINARY(16) NOT NULL,
   category_id INT(10) UNSIGNED DEFAULT NULL,
   varname VARCHAR(64) NOT NULL COLLATE utf8_bin,
   caption VARCHAR(255) NOT NULL,
@@ -344,8 +347,8 @@ CREATE TABLE director_job (
   run_interval INT(10) UNSIGNED NOT NULL, -- seconds
   timeperiod_id INT(10) UNSIGNED DEFAULT NULL,
   last_attempt_succeeded ENUM('y', 'n') DEFAULT NULL,
-  ts_last_attempt TIMESTAMP NULL DEFAULT NULL,
-  ts_last_error TIMESTAMP NULL DEFAULT NULL,
+  ts_last_attempt BIGINT(20) NULL DEFAULT NULL,
+  ts_last_error BIGINT(20) NULL DEFAULT NULL,
   last_error_message TEXT DEFAULT NULL,
   PRIMARY KEY (id),
   UNIQUE KEY (job_name),
@@ -651,7 +654,7 @@ CREATE TABLE icinga_host_field (
 CREATE TABLE icinga_host_var (
   host_id INT(10) UNSIGNED NOT NULL,
   varname VARCHAR(255) NOT NULL COLLATE utf8_bin,
-  varvalue TEXT DEFAULT NULL,
+  varvalue MEDIUMTEXT DEFAULT NULL,
   format enum ('string', 'json', 'expression'), -- immer string vorerst
   checksum VARBINARY(20) DEFAULT NULL,
   PRIMARY KEY (host_id, varname),
@@ -1259,6 +1262,8 @@ CREATE TABLE icinga_notification (
   command_id INT(10) UNSIGNED DEFAULT NULL,
   period_id INT(10) UNSIGNED DEFAULT NULL,
   zone_id INT(10) UNSIGNED DEFAULT NULL,
+  users_var VARCHAR(255) DEFAULT NULL,
+  user_groups_var VARCHAR(255) DEFAULT NULL,
   assign_filter TEXT DEFAULT NULL,
   PRIMARY KEY (id),
   UNIQUE INDEX uuid (uuid),
@@ -1454,6 +1459,7 @@ CREATE TABLE import_row_modifier (
   target_property VARCHAR(255) DEFAULT NULL,
   provider_class VARCHAR(128) NOT NULL,
   priority SMALLINT UNSIGNED NOT NULL,
+  filter_expression TEXT DEFAULT NULL,
   description TEXT DEFAULT NULL,
   PRIMARY KEY (id),
   KEY search_idx (property_name),
@@ -1768,6 +1774,7 @@ CREATE TABLE icinga_dependency (
   zone_id INT(10) UNSIGNED DEFAULT NULL,
   assign_filter TEXT DEFAULT NULL,
   parent_service_by_name VARCHAR(255) DEFAULT NULL,
+  redundancy_group VARCHAR(255) DEFAULT NULL,
   PRIMARY KEY (id),
   UNIQUE INDEX uuid (uuid),
   CONSTRAINT icinga_dependency_parent_host
@@ -2308,6 +2315,30 @@ CREATE TABLE branched_icinga_service (
     ON UPDATE CASCADE
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 
+CREATE TABLE branched_icinga_service_set (
+  uuid VARBINARY(16) NOT NULL,
+  branch_uuid VARBINARY(16) NOT NULL,
+  branch_created ENUM('y', 'n') NOT NULL DEFAULT 'n',
+  branch_deleted ENUM('y', 'n') NOT NULL DEFAULT 'n',
+
+  object_name VARCHAR(128) DEFAULT NULL,
+  object_type ENUM('object', 'template', 'external_object') DEFAULT NULL,
+  host VARCHAR(255) DEFAULT NULL,
+  description TEXT DEFAULT NULL,
+  assign_filter TEXT DEFAULT NULL,
+
+
+  imports TEXT DEFAULT NULL,
+  set_null TEXT DEFAULT NULL,
+  PRIMARY KEY (branch_uuid, uuid),
+  INDEX search_object_name (object_name),
+  CONSTRAINT icinga_service_set_branch
+    FOREIGN KEY branch (branch_uuid)
+    REFERENCES director_branch (uuid)
+    ON DELETE CASCADE
+    ON UPDATE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
+
 CREATE TABLE branched_icinga_notification (
   uuid VARBINARY(16) NOT NULL,
   branch_uuid VARBINARY(16) NOT NULL,
@@ -2326,6 +2357,8 @@ CREATE TABLE branched_icinga_notification (
   command VARCHAR(255) DEFAULT NULL,
   period VARCHAR(255) DEFAULT NULL,
   zone VARCHAR(255) DEFAULT NULL,
+  users_var VARCHAR(255) DEFAULT NULL,
+  user_groups_var VARCHAR(255) DEFAULT NULL,
   assign_filter TEXT DEFAULT NULL,
 
   states TEXT DEFAULT NULL,
@@ -2399,6 +2432,7 @@ CREATE TABLE branched_icinga_dependency (
   zone VARCHAR(255) DEFAULT NULL,
   assign_filter TEXT DEFAULT NULL,
   parent_service_by_name VARCHAR(255) DEFAULT NULL,
+  redundancy_group VARCHAR(255) DEFAULT NULL,
 
   imports TEXT DEFAULT NULL,
   set_null TEXT DEFAULT NULL,
@@ -2414,4 +2448,4 @@ CREATE TABLE branched_icinga_dependency (
 
 INSERT INTO director_schema_migration
   (schema_version, migration_time)
-  VALUES (178, NOW());
+  VALUES (191, NOW());
